pilas.motores.motor_qt.MusicaGST

Package pilas :: Package motores :: Module motor_qt :: Class MusicaGST |
[hide private]
[frames] | no frames]

# Class MusicaGST

source code

    SonidoGST --+
                |
               MusicaGST

Instance Methods | [hide private]
__init__(self, media, ruta) | source code
Inherited from `SonidoGST`: `detener`, `reproducir`

Class Variables | [hide private]
Inherited from `SonidoGST`: `deshabilitado`

Method Details | [hide private]

### __init__(self, media, ruta) (Constructor) | source code
Overrides: SonidoGST.__init__